@@ -455,8 +455,8 @@ std::ostream &	operator << (std::ostream &s, const Vec3<T> &v);
 // Reverse multiplication: S * Vec2<T> and S * Vec3<T>
 //----------------------------------------------------
 
-template <class S, class T> Vec2<T>	operator * (S a, const Vec2<T> &v);
-template <class S, class T> Vec3<T>	operator * (S a, const Vec3<T> &v);
+template <class T> Vec2<T>	operator * (T a, const Vec2<T> &v);
+template <class T> Vec3<T>	operator * (T a, const Vec3<T> &v);
 
 
 //-------------------------
@@ -1397,16 +1397,16 @@ operator << (std::ostream &s, const Vec3<T> &v)
 // Implementation of reverse multiplication
 //-----------------------------------------
 
-template <class S, class T>
+template <class T>
 inline Vec2<T>
-operator * (S a, const Vec2<T> &v)
+operator * (T a, const Vec2<T> &v)
 {
     return Vec2<T> (a * v.x, a * v.y);
 }
 
-template <class S, class T>
+template <class T>
 inline Vec3<T>
-operator * (S a, const Vec3<T> &v)
+operator * (T a, const Vec3<T> &v)
 {
     return Vec3<T> (a * v.x, a * v.y, a * v.z);
 }
